Package 'OHCA'
| Title: |
Orchestrating Hi-C analysis with Bioconductor |
| Description: |
The primary aim of this book is to introduce the R user to
Hi-C analysis. This book starts with key concepts important for
the analysis of chromatin conformation capture and then
presents Bioconductor tools that can be leveraged to process,
analyze, explore and visualize Hi-C data. |
| Authors: |
Jacques Serizay [aut, cre] (ORCID:
<https://orcid.org/0000-0002-4295-0624>) |
| Maintainer: |
Jacques Serizay <[email protected]> |
| License: |
MIT + file LICENSE |
| Version: |
1.9.0 |
| Built: |
2026-05-28 06:33:47 UTC |
| Source: |
https://github.com/bioc/OHCA |
Help Index